@@ -27,7 +27,7 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw( create_thumbnail );
 
-our $VERSION = 'v0.1.5';
+our $VERSION = 'v0.2.0';
 
 require XSLoader;
 XSLoader::load('Ithumb::XS', $VERSION);
@@ -40,23 +40,40 @@ __END__
 
   use Ithumb::XS ();
 
-  Ithumb::XS::create_thumbnail('src.png', 100, 100, 'output.png');
+  Ithumb::XS::create_thumbnail({
+      width     => 800,
+      height    => 600,
+      src_image => 'source_image.jpg',
+      dst_image => 'destination_result_image.jpg'
+  });
+
+OO-interface:
+
+  use Ithumb::XS;
+
+  my $ithumb = Ithumb::XS->new;
+  $ithumb->convert({
+      width     => 800,
+      height    => 600,
+      src_image => 'source_image.jpg',
+      dst_image => 'destination_result_image.jpg'
+  });
 
 =head1 METHODS
 
-=head2 create_thumbnail($src_image, $width, $height, $dst_image);
+=head2 create_thumbnail($);
 
 Creates a small copy (with cropping) of the image.
 
 =over 12
 
-=item C<$src_image> - path to source image
-
 =item C<$width> - destination width
 
 =item C<$height> - destination height
 
-=item C<$dst_image> - path to destionation result image
+=item C<$src_image> - path to the source image
+
+=item C<$dst_image> - path to the destionation result image
   
 =back
 
@@ -64,7 +81,7 @@ Creates a small copy (with cropping) of the image.
 
 BSD 3-Clause License
 
-Copyright (c) 2018, Peter P. Neuromantic <p.brovchenko@protonmail.com>
+Copyright (c) 2018, 2019 Peter P. Neuromantic <p.brovchenko@protonmail.com>
 All rights reserved.
 
 See LICENSE file for more details.
